ScateSDK class
Constructors
- ScateSDK()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
AddListener(
ScateEvents eventType, Function listener) → void -
AdjustInitiated(
) → void -
AdjustSetToRevenuecat(
) → void -
AllServicesInitialized(
) → void -
ATTPermissionDenied(
) → void -
ATTPermissionGranted(
) → void -
ATTPromptShown(
) → void -
BannerAdShown(
) → void -
ClearListeners(
ScateEvents eventType) → void -
CloseOnboarding(
) → void -
ClosePaidProductLoadingScreen(
) → void -
ClosePaywall(
) → void -
ContentCreateFail(
) → void -
ContentCreateStart(
) → void -
ContentCreateSuccess(
) → void -
DailyStreakClaimed(
) → void -
DailyStreakClosed(
) → void -
DailyStreakShown(
) → void -
Event(
String name, {Map< String, dynamic> ? parameters}) → Future<void> -
EventWithValue(
String name, String value) → Future< void> -
FeatureClicked(
String feature) → void -
FirebaseRemoteInitiated(
) → void -
GetAdjustId(
void callback(String adid)) → Future< void> -
GetRemoteConfig(
String key, String defaultValue) → Future< String?> -
GetUserID(
) → Future< String?> -
HandleEvent(
String name, dynamic event) → void -
HomeScreenOpen(
) → void -
InAppPurchaseSuccess(
) → void -
Init(
String appID, {bool firebaseUserIdSyncEnabled = true, bool debug = false}) → Future< void> -
InitAdjust(
String adjustToken, {bool noATT = false}) → Future< void> -
InterstitialAdClosed(
) → void -
InterstitialAdShown(
) → void -
LocationPermissionDenied(
) → void -
LocationPermissionGranted(
) → void -
LoginSuccess(
String source) → void -
NotificationPermissionDenied(
) → void -
NotificationPermissionGranted(
) → void -
OnboardingFinish(
) → void -
OnboardingPaywallClosed(
) → void -
OnboardingPaywallShown(
) → void -
OnboardingStart(
) → void -
OnboardingStep(
String step) → void -
PaywallAttempted(
String paywall) → void -
PaywallCancelled(
String paywall) → void -
PaywallClosed(
String paywall) → void -
PaywallPurchased(
String paywall) → void -
PaywallShown(
String paywall) → void -
RemoveListener(
ScateEvents eventType) → void -
RevenuecatInitiated(
) → void -
RewardedAdClaimed(
) → void -
RewardedAdClosed(
) → void -
RewardedAdShown(
) → void -
SetAdid(
String adid) → Future< void> -
ShowEventList(
) → void -
ShowOnboarding(
String jsonString) → void -
ShowPaidProductLoadingScreen(
) → void -
ShowPaywall(
String jsonString) → void -
SplashCompleted(
) → void -
SubsCancel(
) → void -
SubscriptionSuccess(
) → void -
SubsFail(
) → void -
SubsStart(
) → void -
SubsSuccess(
) → void -
TabClicked(
String tab) → void